@@ -1,18 +1,16 @@
 """
 Fetch the LIGO BigDog time-domain dataset
 """
-from __future__ import print_function, division
-
 import os
-from ..py3k_compat import BytesIO
+from io import BytesIO
 from gzip import GzipFile
 import numpy as np
 
 from . import get_data_home
 from .tools import download_with_progress_bar
 
-DATA_URL_LARGE = ('http://www.astro.washington.edu/users/ivezic/'
-                  'DMbook/LIGO/hoft.968653908-968655956.H1.dat.gz')
+DATA_URL_LARGE = ('https://github.com/astroML/astroML-data/raw/main/datasets/'
+                  'hoft.968653908-968655956.H1.dat.gz')
 LOCAL_FILE_LARGE = 'LIGO_large.npy'
 
 DATA_URL = 'http://www.ligo.org/science/GW100916/HLV-strain.txt'
@@ -26,7 +24,7 @@ def fetch_LIGO_large(data_home=None, download_if_missing=True):
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : optional, default=True
         If False, raise a IOError if the data is not locally available
@@ -72,7 +70,7 @@ def fetch_LIGO_bigdog(data_home=None, download_if_missing=True):
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : optional, default=True
         If False, raise a IOError if the data is not locally available
@@ -87,12 +85,12 @@ def fetch_LIGO_bigdog(data_home=None, download_if_missing=True):
     Examples
     --------
     >>> from astroML.datasets import fetch_LIGO_bigdog
-    >>> data = fetch_LIGO_bigdog()  # doctest: +IGNORE_OUTPUT
-    >>> print(data.dtype.names)
+    >>> data = fetch_LIGO_bigdog()  # doctest: +IGNORE_OUTPUT +REMOTE_DATA
+    >>> print(data.dtype.names)  # doctest: +REMOTE_DATA
     ('t', 'Hanford', 'Livingston', 'Virgo')
-    >>> print(data['t'][:3])
+    >>> print(data['t'][:3])  # doctest: +REMOTE_DATA
     [  0.00000000e+00   6.10400000e-05   1.22070000e-04]
-    >>> print(data['Hanford'][:3])
+    >>> print(data['Hanford'][:3])  # doctest: +REMOTE_DATA
     [  1.26329846e-17   1.26846778e-17   1.19187381e-17]
     """
     data_home = get_data_home(data_home)
