@@ -1,16 +1,13 @@
-from __future__ import print_function, division
-
 import os
 
 import numpy as np
+from astropy.table import Table
 
 from . import get_data_home
-from .tools import download_with_progress_bar
 
-DATA_URL = ("http://www.astro.washington.edu/users/"
-            "ivezic/DMbook/data/imagingSample_20sqdeg.fit")
-DATA_URL = ("http://www.astro.washington.edu/users/"
-            "ivezic/DMbook/data/sgSDSSimagingSample.fit")
+
+DATA_URL = ("https://github.com/astroML/astroML-data/raw/main/datasets/"
+            "sgSDSSimagingSample.fit.gz")
 
 
 def fetch_imaging_sample(data_home=None, download_if_missing=True):
@@ -20,7 +17,7 @@ def fetch_imaging_sample(data_home=None, download_if_missing=True):
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : optional, default=True
         If False, raise a IOError if the data is not locally available
@@ -34,14 +31,16 @@ def fetch_imaging_sample(data_home=None, download_if_missing=True):
     Examples
     --------
     >>> from astroML.datasets import fetch_imaging_sample
-    >>> data = fetch_imaging_sample()  # doctest: +IGNORE_OUTPUT
-    >>> data.shape  # number of objects in dataset
+    >>> data = fetch_imaging_sample()  # doctest: +IGNORE_OUTPUT +REMOTE_DATA
+    >>> # number of objects in dataset
+    >>> data.shape  # doctest: +REMOTE_DATA
     (330753,)
-    >>> print(data.dtype.names[:5])  # names of the first five columns
+    >>> # names of the first five columns
+    >>> print(data.dtype.names[:5])  # doctest: +REMOTE_DATA
     ('ra', 'dec', 'run', 'rExtSFD', 'uRaw')
-    >>> print(data['ra'][:2])
+    >>> print(data['ra'][:2])  # doctest: +REMOTE_DATA
     [0.358174 0.358382]
-    >>> print(data['dec'][:2])
+    >>> print(data['dec'][:2])  # doctest: +REMOTE_DATA
     [-0.508718 -0.551157]
 
     Notes
@@ -92,9 +91,6 @@ def fetch_imaging_sample(data_home=None, download_if_missing=True):
           p.modelMag_r < 22.5
         --- the end of query
     """
-    # fits is an optional dependency: don't import globally
-    from astropy.io import fits
-
     data_home = get_data_home(data_home)
 
     archive_file = os.path.join(data_home, os.path.basename(DATA_URL))
@@ -104,8 +100,9 @@ def fetch_imaging_sample(data_home=None, download_if_missing=True):
             raise IOError('data not present on disk. '
                           'set download_if_missing=True to download')
 
-        fitsdata = download_with_progress_bar(DATA_URL)
-        open(archive_file, 'wb').write(fitsdata)
+        data = Table.read(DATA_URL)
+        data.write(archive_file)
+    else:
+        data = Table.read(archive_file)
 
-    hdulist = fits.open(archive_file)
-    return np.asarray(hdulist[1].data)
+    return np.asarray(data)
