@@ -8,8 +8,6 @@ http://www.nsatlas.org/data
 This function fetches a ~50MB subset of that data.  This subset is created
 using the code that can be found at examples/datasets/truncate_nsa_data.py
 """
-from __future__ import print_function, division
-
 import os
 
 import numpy as np
@@ -18,8 +16,8 @@ from .tools import download_with_progress_bar
 from . import get_data_home
 
 
-DATA_URL = ('http://www.astro.washington.edu/users/ivezic/'
-            'DMbook/nsa_v0_1_2_reduced.npy')
+DATA_URL = ('https://github.com/astroML/astroML-data/raw/main/datasets/'
+            'nsa_v0_1_2_reduced.npy')
 
 ARCHIVE_FILE = os.path.basename(DATA_URL)
 
@@ -32,7 +30,7 @@ def fetch_nasa_atlas(data_home=None,
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : optional, default=True
         If False, raise a IOError if the data is not locally available
