@@ -1,11 +1,9 @@
-from __future__ import print_function, division
-
 import os
 import numpy as np
 from . import get_data_home
 from .tools import download_with_progress_bar
 
-DATA_URL = ("https://github.com/astroML/astroML-data/raw/master/datasets/"
+DATA_URL = ("https://github.com/astroML/astroML-data/raw/main/datasets/"
             "spec4000.npz")
 
 
@@ -71,7 +69,7 @@ def fetch_sdss_corrected_spectra(data_home=None,
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : optional, default=True
         If False, raise a IOError if the data is not locally available
