@@ -1,7 +1,4 @@
-from __future__ import print_function, division
-
 import os
-import sys
 
 import numpy as np
 from . import get_data_home
@@ -25,7 +22,7 @@ def fetch_sdss_galaxy_colors(data_home=None, download_if_missing=True):
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : optional, default=True
         If False, raise a IOError if the data is not locally available
@@ -63,10 +60,9 @@ def fetch_sdss_galaxy_colors(data_home=None, download_if_missing=True):
         print("finished.")
 
         kwargs = {'delimiter': ',', 'skip_header': 2,
-                  'names': GAL_COLORS_NAMES, 'dtype': None}
-
-        if sys.version_info[0] >= 3:
-            kwargs['encoding'] = 'ascii'
+                  'names': GAL_COLORS_NAMES, 'dtype': None,
+                  'encoding': 'ascii',
+                  }
 
         data = np.genfromtxt(output, **kwargs)
         np.save(archive_file, data)
