@@ -1,14 +1,13 @@
-from __future__ import print_function
-
 import os
 
 import numpy as np
+from astropy.table import Table
 
 from . import get_data_home
-from .tools import download_with_progress_bar
 
-DATA_URL = ("http://www.astro.washington.edu/users/ivezic/"
-            "DMbook/data/SDSSssppDR9_rerun122.fit")
+
+DATA_URL = ("https://github.com/astroML/astroML-data/raw/main/datasets/"
+            "SDSSssppDR9_rerun122.fit.gz")
 
 
 def compute_distances(data):
@@ -24,10 +23,10 @@ def compute_distances(data):
     """
     # extinction terms from Berry et al
     Ar = data['Ar']
-    Au = 1.810 * Ar
+    # Au = 1.810 * Ar
     Ag = 1.400 * Ar
     Ai = 0.759 * Ar
-    Az = 0.561 * Ar
+    # Az = 0.561 * Ar
 
     # compute corrected mags and colors
     gmag = data['gpsf'] - Ag
@@ -56,7 +55,7 @@ def fetch_sdss_sspp(data_home=None, download_if_missing=True, cleaned=False):
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : bool (optional) default=True
         If False, raise a IOError if the data is not locally available
@@ -96,19 +95,20 @@ def fetch_sdss_sspp(data_home=None, download_if_missing=True, cleaned=False):
     Examples
     --------
     >>> from astroML.datasets import fetch_sdss_sspp
-    >>> data = fetch_sdss_sspp()  # doctest: +IGNORE_OUTPUT
-    >>> data.shape  # number of objects in dataset
+    >>> data = fetch_sdss_sspp()  # doctest: +IGNORE_OUTPUT +REMOTE_DATA
+    >>> # number of objects in dataset
+    >>> data.shape  # doctest: +REMOTE_DATA
     (327260,)
-    >>> print(data.dtype.names[:5])  # names of the first five columns
+    >>> # names of the first five columns
+    >>> print(data.dtype.names[:5])  # doctest: +REMOTE_DATA
     ('ra', 'dec', 'Ar', 'upsf', 'uErr')
-    >>> print(data['ra'][:1])  # first RA value
+    >>> # first RA value
+    >>> print(data['ra'][:1])  # doctest: +REMOTE_DATA
     [49.6275024]
-    >>> print(data['dec'][:1])  # first DEC value
+    >>> # first DEC value
+    >>> print(data['dec'][:1])  # doctest: +REMOTE_DATA
     [-1.04175591]
     """
-    # fits is an optional dependency: don't import globally
-    from astropy.io import fits
-
     data_home = get_data_home(data_home)
 
     archive_file = os.path.join(data_home, os.path.basename(DATA_URL))
@@ -118,12 +118,10 @@ def fetch_sdss_sspp(data_home=None, download_if_missing=True, cleaned=False):
             raise IOError('data not present on disk. '
                           'set download_if_missing=True to download')
 
-        fitsdata = download_with_progress_bar(DATA_URL)
-        open(archive_file, 'wb').write(fitsdata)
-
-    hdulist = fits.open(archive_file)
-
-    data = np.asarray(hdulist[1].data)
+        data = Table.read(DATA_URL)
+        data.write(archive_file)
+    else:
+        data = Table.read(archive_file)
 
     if cleaned:
         # -1.1 < FeH < 0.1
@@ -150,4 +148,4 @@ def fetch_sdss_sspp(data_home=None, download_if_missing=True, cleaned=False):
         # abs(radVel) < 100 km/s
         data = data[(abs(data['radVel']) < 100)]
 
-    return data
+    return np.asarray(data)
