@@ -105,7 +105,7 @@ def scatter_contour(x, y,
             # this works in newer matplotlib versions
             from matplotlib.path import Path
             points_inside = Path(outer_poly).contains_points(X)
-        except:
+        except ImportError:
             # this works in older matplotlib versions
             import matplotlib.nxutils as nx
             points_inside = nx.points_inside_poly(X, outer_poly)
