@@ -1,7 +1,11 @@
 import numpy as np
-from ..utils import check_random_state
+from sklearn.utils import check_random_state
 
-from astropy.stats import LombScargle
+try:
+    # astropy.timeseries is new in v3.2
+    from astropy.timeseries import LombScargle
+except ImportError:
+    from astropy.stats import LombScargle
 
 from ..utils.decorators import deprecated
 from ..utils.exceptions import AstroMLDeprecationWarning
@@ -152,8 +156,7 @@ def lomb_scargle_AIC(P, y, dy, n_harmonics=1):
     P, y, dy = map(np.asarray(P, y, dy))
     w = 1. / dy ** 2
     mu = np.dot(w, y) / w.sum()
-    N = len(y)
-    return np.sum(((y_obs - mu) / dy) ** 2) * P - (2 * n_harmonics + 1) * 2
+    return np.sum(((y - mu) / dy) ** 2) * P - (2 * n_harmonics + 1) * 2
 
 
 def lomb_scargle_BIC(P, y, dy, n_harmonics=1):
@@ -306,7 +309,7 @@ def search_frequencies(t, y, dy,
     return omega_best[i], power_best[i]
 
 
-class MultiTermFit(object):
+class MultiTermFit:
     """Multi-term Fourier fit to a light curve
 
     Parameters
